pub struct EdwardsPoint {
pub(crate) X: FieldElement,
pub(crate) Y: FieldElement,
pub(crate) Z: FieldElement,
pub(crate) T: FieldElement,
}Expand description
Represent points on the (untwisted) edwards curve using Extended Homogenous Projective Co-ordinates (x, y) -> (X/Z, Y/Z, Z, T) a = 1, d = -39081 XXX: Make this more descriptive Should this be renamed to EdwardsPoint so that we are consistent with Dalek crypto? Necessary as ExtendedPoint is not regular lingo?
Fields
X: FieldElementY: FieldElementZ: FieldElementT: FieldElementImplementations
Sourceimpl EdwardsPoint
impl EdwardsPoint
Sourcepub fn to_montgomery(&self) -> MontgomeryPoint
pub fn to_montgomery(&self) -> MontgomeryPoint
Convert this point to MontgomeryPoint
Sourcepub fn scalar_mul(&self, scalar: &EdwardsScalar) -> Self
pub fn scalar_mul(&self, scalar: &EdwardsScalar) -> Self
Generic scalar multiplication to compute s*P
Sourcepub fn add(&self, other: &EdwardsPoint) -> Self
pub fn add(&self, other: &EdwardsPoint) -> Self
Add two points
Sourcepub fn is_on_curve(&self) -> Choice
pub fn is_on_curve(&self) -> Choice
Check if this point is on the curve
Sourcepub fn to_affine(&self) -> AffinePoint
pub fn to_affine(&self) -> AffinePoint
Convert this point to an AffinePoint.
pub(crate) fn to_twisted(self) -> TwistedExtensiblePoint
Sourcepub fn is_torsion_free(&self) -> Choice
pub fn is_torsion_free(&self) -> Choice
Determine if this point is “torsion-free”, i.e., is contained in the prime-order subgroup.
Return
trueifselfhas zero torsion component and is in the prime-order subgroup;falseifselfhas a nonzero torsion component and is not in the prime-order subgroup.